==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/LabelClickEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { LabelClickEventArgsDescription } from "./LabelClickEventArgsDescription";
/**
 * @hidden
 */
var LabelClickEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(LabelClickEventArgsDescriptionMetadata, _super);
    function LabelClickEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    LabelClickEventArgsDescriptionMetadata.b = function (a) {
        if (LabelClickEventArgsDescriptionMetadata.a == null) {
            LabelClickEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            LabelClickEventArgsDescriptionMetadata.c(LabelClickEventArgsDescriptionMetadata.a);
        }
        if (a.g(LabelClickEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.s(LabelClickEventArgsDescriptionMetadata.a);
    };
    LabelClickEventArgsDescriptionMetadata.c = function (a) {
        a.item("AllowSliceClick", "Boolean");
    };
    LabelClickEventArgsDescriptionMetadata.d = function (a) {
        LabelClickEventArgsDescriptionMetadata.b(a);
        a.u("LabelClickEventArgs", function () { return new LabelClickEventArgsDescription(); });
        a.t("LabelClickEventArgs", LabelClickEventArgsDescriptionMetadata.a);
    };
    LabelClickEventArgsDescriptionMetadata.$t = markType(LabelClickEventArgsDescriptionMetadata, 'LabelClickEventArgsDescriptionMetadata');
    LabelClickEventArgsDescriptionMetadata.a = null;
    return LabelClickEventArgsDescriptionMetadata;
}(Base));
export { LabelClickEventArgsDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/LabelClickEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { LabelClickEventArgsDescription } from "./LabelClickEventArgsDescription";
/**
 * @hidden
 */
var LabelClickEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(LabelClickEventArgsDescriptionMetadata, _super);
    function LabelClickEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    LabelClickEventArgsDescriptionMetadata.b = function (a) {
        if (LabelClickEventArgsDescriptionMetadata.a == null) {
            LabelClickEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            LabelClickEventArgsDescriptionMetadata.c(LabelClickEventArgsDescriptionMetadata.a);
        }
        if (a.j(LabelClickEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(LabelClickEventArgsDescriptionMetadata.a);
    };
    LabelClickEventArgsDescriptionMetadata.c = function (a) {
        a.item("AllowSliceClick", "Boolean");
    };
    LabelClickEventArgsDescriptionMetadata.d = function (a) {
        LabelClickEventArgsDescriptionMetadata.b(a);
        a.aa("LabelClickEventArgs", function () { return new LabelClickEventArgsDescription(); });
        a.z("LabelClickEventArgs", LabelClickEventArgsDescriptionMetadata.a);
    };
    LabelClickEventArgsDescriptionMetadata.$t = markType(LabelClickEventArgsDescriptionMetadata, 'LabelClickEventArgsDescriptionMetadata');
    LabelClickEventArgsDescriptionMetadata.a = null;
    return LabelClickEventArgsDescriptionMetadata;
}(Base));
export { LabelClickEventArgsDescriptionMetadata };
